{% extends "base.html" %}
{% block content %}
  {% if main_page_content %}
    <p class="mb-2">
      <a style="font-size: 0.9em" href="#packages">↓ Packages</a>
    </p>
    <div class="block content">{{ main_page_content | safe }}</div>
  {% endif %}
  <h3 id="packages" class="title is-3">
    Packages
  </h3>
  <div class="block">This site contains the documentation for the following Protobuf packages.</div>
  <div class="block">
  {% for p in packages %}
    <h5 class="title is-5">
      {% if p.name %}
        <a href="{{ p.name }}.html">{{ p.name }}</a>
      {% else %}
        <a href="__default.html">(Default package)</a>
      {% endif %}
    </h4>
    {% if p.description_html %}
    <div style="margin-top: -0.5rem; margin-bottom: 2.5rem">
      {{ p.description_html | safe }}
    </div>
    {% endif %}
  {% endfor %}
  </div>
{% endblock %}
